﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace CsCgrep
{
    public partial class SettingDialog : Form
    {
        /// <summary>
        /// 親ウィンドウ
        /// </summary>
        private MainWindow parent;

        public SettingDialog(MainWindow parent)
        {
            InitializeComponent();

            this.parent = parent;

            editorPathBox.Text = parent.AppSettings.ExternalEditorPath;
        }

        /// <summary>
        /// クリアボタンクリック時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void clearButton_Click(object sender, EventArgs e)
        {
            if (!placeCheckBox.Checked &&
                !keywordCheckBox.Checked &&
                !fileCheckBox.Checked)
            {
                MessageUtil.ShowAlert("クリアする履歴を選択してください。");
                return;
            }

            DialogResult r = MessageUtil.ShowQuestion("履歴をクリアしてもよろしいですか？");

            if (r == DialogResult.No)
            {
                return;
            }

            if (placeCheckBox.Checked)
            {
                parent.ClearFolderHistory();
            }

            if (keywordCheckBox.Checked)
            {
                parent.ClearKeywordHistory();
            }

            if (fileCheckBox.Checked)
            {
                parent.ClearFileNameHistory();
            }

            MessageUtil.ShowInfo("履歴をクリアしました。");
        }

        /// <summary>
        /// 参照ボタンがクリックされた時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void browseButton_Click(object sender, EventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();

            dialog.Title = "外部エディタの選択";

            dialog.InitialDirectory =
                Environment.GetFolderPath(Environment.SpecialFolder.ProgramFiles);

            dialog.Filter = "アプリケーション(*.exe)|*.exe";

            DialogResult result = dialog.ShowDialog();

            if (result == DialogResult.OK)
            {
                if (! dialog.FileName.EndsWith(".exe"))
                {
                    MessageUtil.ShowAlert("アプリケーションを指定してください。");
                }
                else
                {
                    editorPathBox.Text = dialog.FileName;
                }
            }

        }

        /// <summary>
        /// OKボタンクリック時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void okButton_Click(object sender, EventArgs e)
        {
            // 外部エディタのパスを保存
            parent.AppSettings.ExternalEditorPath = editorPathBox.Text;

            Close();
        }

        /// <summary>
        /// キャンセルボタンクリック時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void cancelButton_Click(object sender, EventArgs e)
        {
            Close();
        }
    }
}
